#!/usr/bin/perl -w
use POSIX;
use strict;
use Net::Rsh;
use lib "/usr/local/nagios/libexec";
use utils qw($TIMEOUT %ERRORS &print_revision &support);

my $rshell = Net::Rsh->new();
my $host = $ARGV[0];
my $command = "/usr/local/netsaint/libexec/check_netsaint /usr/local/netsaint/var/status.log 5 '/usr/local/netsaint/bin/netsaint'";
my @rshresults = ();
my $x = 0;
my $i = "";

if (!defined($host)) {
	print "No host specified!\n";
	exit $ERRORS{'UNKNOWN'};
}

$SIG{ALRM} = sub { die "timeout" };

eval {
	alarm(60); # time out after 60 seconds per command.
	@rshresults = $rshell->rsh($host, "root", "netsaint", $command);
	alarm(0);
};

open (RSHLOG, ">>/usr/local/nagios/libexec/RSH.LOG.TEXT");
	print RSHLOG "--------------------------\n";
	print RSHLOG "HOST: " . $host . "\n";
	print RSHLOG "COMMAND: " . $command . "\n";
	print RSHLOG "ERRORS:\n";
	foreach $i ($@) {
		print RSHLOG $i;
	}
	print RSHLOG "RSH RESULTS:\n";
	print RSHLOG "$rshresults[0]\n";
	print RSHLOG "--------------------------\n";
close RSHLOG;

if ($@) {
	if ($@ =~ /timeout/) {
		print "check_netsaint.pl: " . $host . " timed out during rsh operation. $rshresults[0].\n";
		exit $ERRORS{'UNKNOWN'};
	}
} else {
	if ($rshresults[0] =~ /Error/) {
		print "$rshresults[0]\n";
		exit $ERRORS{'CRITICAL'};
	} else {
		print "$rshresults[0]\n";
		exit $ERRORS{'OK'};
	}
}

print "should have never made it to here.\n";
exit $ERRORS{'UNKNOWN'};
